@@ -22,11 +22,11 @@ class AbcpApi:
 
     def __init__(
             self,
-            loop: Optional[Union[asyncio.BaseEventLoop, asyncio.AbstractEventLoop]] = None,
-            connections_limit: int = None,
             host: str = None,
             login: str = None,
             password: str = None,
+            loop: Optional[Union[asyncio.BaseEventLoop, asyncio.AbstractEventLoop]] = None,
+            connections_limit: int = None,
             validate: bool = True,
             timeout: typing.Optional[typing.Union[int, float, aiohttp.ClientTimeout]] = None,
     ):
@@ -40,8 +40,6 @@ class AbcpApi:
         :type password: 'str' (md5 hash)
         :param validate: Validate host, login, password
         :type validate: bool
-        :param admin: Can use Api.Admin or not
-        :type admin: bool
         :raise: when host, login or password is invalid
         """
 
